/// <reference types="node" />
import { AppContext } from 'next/app';
import { Store, Middleware, Action } from 'redux';
import { GetServerSideProps, GetServerSidePropsContext, GetStaticProps, GetStaticPropsContext, NextComponentType, NextPageContext } from 'next';
export declare type MakeStore<S extends Store> = (init: {
    context: Context;
    reduxWrapperMiddleware: Middleware;
}) => S;
export interface InitStoreOptions<S extends Store> {
    makeStore: MakeStore<S>;
    context?: Context;
    config: Config<S>;
}
export declare enum Source {
    GIAP = "GIAP",
    GIPP = "GIPP",
    GSP = "GSP",
    GSSP = "GSSP"
}
export declare const createWrapper: <S extends Store<any, import("redux").AnyAction>>(makeStore: MakeStore<S>, config?: Config<S>) => {
    getServerSideProps: <P extends {} = any>(callback: GetServerSidePropsCallback<S, P>) => GetServerSideProps<P, import("querystring").ParsedUrlQuery, import("next").PreviewData>;
    getStaticProps: <P_1 extends {} = any>(callback: GetStaticPropsCallback<S, P_1>) => GetStaticProps<P_1, import("querystring").ParsedUrlQuery, import("next").PreviewData>;
    getInitialAppProps: <P_2 extends {} = any>(callback: AppCallback<S, P_2>) => ({ Component, ctx }: AppContext) => Promise<{
        pageProps: P_2;
    }> | {
        pageProps: P_2;
    };
    getInitialPageProps: <P_3 extends {} = any>(callback: PageCallback<S, P_3>) => ((context: NextPageContext) => P_3 | Promise<P_3>) | undefined;
    useStore: () => S;
    useHydration: ({ reduxWrapperActionsGSSP, reduxWrapperActionsGSP, reduxWrapperActionsGIAP, reduxWrapperActionsGIPP, }: PageProps | any) => {
        hydrating: boolean;
    };
};
export declare type Context = NextPageContext | AppContext | GetStaticPropsContext | GetServerSidePropsContext;
export interface Config<S extends Store> {
    serialize?: (actions: Action[]) => Action[];
    deserialize?: (actions: Action[]) => Action[];
    debug?: boolean;
}
export interface PageProps {
    reduxWrapperActionsGIAP?: Action[];
    reduxWrapperActionsGIPP?: Action[];
    reduxWrapperActionsGSSP?: Action[];
    reduxWrapperActionsGSP?: Action[];
}
export interface WrapperProps<P extends Object> {
    reduxWrapperActions: Action[];
    initialProps: P;
}
export declare type GetStaticPropsCallback<S extends Store, P extends {
    [key: string]: any;
}> = (store: S) => GetStaticProps<P>;
export declare type GetServerSidePropsCallback<S extends Store, P extends {
    [key: string]: any;
}> = (store: S) => GetServerSideProps<P>;
export declare type PageCallback<S extends Store, P> = (store: S) => NextComponentType<NextPageContext, P, P>['getInitialProps'];
export declare type AppCallback<S extends Store, P> = (store: S) => ({ Component, ctx }: AppContext) => Promise<{
    pageProps: P;
}> | {
    pageProps: P;
};
export declare type Callback<S extends Store, P extends {
    [key: string]: any;
}> = GetStaticPropsCallback<S, P> | GetServerSidePropsCallback<S, P> | PageCallback<S, P> | AppCallback<S, P>;
